Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS Cost Explorer Service.

Actions, resources, and condition keys for AWS Cost Explorer Service - Service Authorization Reference

# Actions, resources, and condition keys for AWS Cost Explorer Service

AWS Cost Explorer Service (service prefix: `ce` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

###### Topics

- Actions defined by AWS Cost Explorer Service
- Resource types defined by AWS Cost Explorer Service
- Condition keys for AWS Cost Explorer Service

## Actions defined by AWS Cost Explorer Service

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column of the Actions table indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") to which the policy applies in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. If the action has one or more required resources, the caller must have permission to use the action with those resources. Required resources are indicated in the table with an asterisk (*). If you limit resource access with the `Resource` element in an IAM policy, you must include an ARN or pattern for each required resource type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one of the optional resource types.

The Condition keys column of the Actions table includes keys that you can specify in a policy statement's `Condition` element. For more information on the condition keys that are associated with resources for the service, see the Condition keys column of the Resource types table.

###### Note

Resource condition keys are listed in the Resource types table. You can find a link to the resource type that applies to an action in the Resource types (*required) column of the Actions table. The resource type in the Resource types table includes the Condition keys column, which are the resource condition keys that apply to an action in the Actions table.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
CreateAnomalyMonitor | Grants permission to create a new Anomaly Monitor | Write |  | aws:RequestTag/${TagKey} aws:TagKeys |
CreateAnomalySubscription | Grants permission to create a new Anomaly Subscription | Write |  | aws:RequestTag/${TagKey} aws:TagKeys |
CreateCostCategoryDefinition | Grants permission to create a new Cost Category with the requested name and rules | Write |  | aws:RequestTag/${TagKey} aws:TagKeys |
CreateNotificationSubscription [permission only] | Grants permission to create Reservation expiration alerts | Write |  |  |
CreateReport [permission only] | Grants permission to create Cost Explorer Reports | Write |  |  |
DeleteAnomalyMonitor | Grants permission to delete an Anomaly Monitor | Write | anomalymonitor* |  |
| aws:ResourceTag/${TagKey} |
DeleteAnomalySubscription | Grants permission to delete an Anomaly Subscription | Write | anomalysubscription* |  |
| aws:ResourceTag/${TagKey} |
DeleteCostCategoryDefinition | Grants permission to delete a Cost Category | Write | costcategory* |  |
| aws:ResourceTag/${TagKey} |
DeleteNotificationSubscription [permission only] | Grants permission to delete Reservation expiration alerts | Write |  |  |
DeleteReport [permission only] | Grants permission to delete Cost Explorer Reports | Write |  |  |
DescribeCostCategoryDefinition | Grants permission to retrieve descriptions such as the name, ARN, rules, definition, and effective dates of a Cost Category | Read | costcategory* |  |
| aws:ResourceTag/${TagKey} |
DescribeNotificationSubscription [permission only] | Grants permission to view Reservation expiration alerts | Read |  |  |
DescribeReport [permission only] | Grants permission to view Cost Explorer Reports page | Read |  |  |
GetAnomalies | Grants permission to retrieve anomalies | Read | anomalymonitor* |  |
| aws:ResourceTag/${TagKey} |
GetAnomalyMonitors | Grants permission to query Anomaly Monitors | Read | anomalymonitor* |  |
| aws:ResourceTag/${TagKey} |
GetAnomalySubscriptions | Grants permission to query Anomaly Subscriptions | Read | anomalysubscription* |  |
| aws:ResourceTag/${TagKey} |
GetConsoleActionSetEnforced [permission only] | Grants permission to view whether existing or fine-grained IAM actions are being used to control authorization to Billing, Cost Management, and Account consoles | Read |  |  |
GetCostAndUsage | Grants permission to retrieve the cost and usage metrics for your account | Read |  |  |
GetCostAndUsageWithResources | Grants permission to retrieve the cost and usage metrics with resources for your account | Read |  |  |
GetCostCategories | Grants permission to query Cost Catagory names and values for a specified time period | Read |  |  |
GetCostForecast | Grants permission to retrieve a cost forecast for a forecast time period | Read |  |  |
GetDimensionValues | Grants permission to retrieve all available filter values for a filter for a period of time | Read |  |  |
GetPreferences [permission only] | Grants permission to view Cost Explorer Preferences page | Read |  |  |
GetReservationCoverage | Grants permission to retrieve the reservation coverage for your account | Read |  |  |
GetReservationPurchaseRecommendation | Grants permission to retrieve the reservation recommendations for your account | Read |  |  |
GetReservationUtilization | Grants permission to retrieve the reservation utilization for your account | Read |  |  |
GetRightsizingRecommendation | Grants permission to retrieve the rightsizing recommendations for your account | Read |  |  |
GetSavingsPlanPurchaseRecommendationDetails | Grants permission to retrieve the Savings Plan recommendation details for your account | Read |  |  |
GetSavingsPlansCoverage | Grants permission to retrieve the Savings Plans coverage for your account | Read |  |  |
GetSavingsPlansPurchaseRecommendation | Grants permission to retrieve the Savings Plans recommendations for your account | Read |  |  |
GetSavingsPlansUtilization | Grants permission to retrieve the Savings Plans utilization for your account | Read |  |  |
GetSavingsPlansUtilizationDetails | Grants permission to retrieve the Savings Plans utilization details for your account | Read |  |  |
GetTags | Grants permission to query tags for a specified time period | Read |  |  |
GetUsageForecast | Grants permission to retrieve a usage forecast for a forecast time period | Read |  |  |
ListCostAllocationTags | Grants permission to list Cost Allocation Tags | List |  |  |
ListCostCategoryDefinitions | Grants permission to retrieve names, ARN, and effective dates for all Cost Categories | List |  |  |
ListSavingsPlansPurchaseRecommendationGeneration | Grants permission to retrieve a list of your historical recommendation generations | List |  |  |
ListTagsForResource | Grants permission to list tags for a Cost Explorer resource | Read | anomalymonitor |  |
anomalysubscription |  |
costcategory |  |
| aws:ResourceTag/${TagKey} |
ProvideAnomalyFeedback | Grants permission to provide feedback on detected anomalies | Write |  |  |
StartSavingsPlansPurchaseRecommendationGeneration | Grants permission to request a Savings Plans recommendation generation | Write |  |  |
TagResource | Grants permission to tag a Cost Explorer resource | Tagging | anomalymonitor |  |
anomalysubscription |  |
costcategory |  |
| aws:TagKeys aws:RequestTag/${TagKey} aws:ResourceTag/${TagKey} |
UntagResource | Grants permission to remove tags from a Cost Explorer resource | Tagging | anomalymonitor |  |
anomalysubscription |  |
costcategory |  |
| aws:TagKeys aws:ResourceTag/${TagKey} |
UpdateAnomalyMonitor | Grants permission to update an existing Anomaly Monitor | Write | anomalymonitor* |  |
| aws:ResourceTag/${TagKey} |
UpdateAnomalySubscription | Grants permission to update an existing Anomaly Subscription | Write | anomalysubscription* |  |
| aws:ResourceTag/${TagKey} |
UpdateConsoleActionSetEnforced [permission only] | Grants permission to change whether existing or fine-grained IAM actions will be used to control authorization to Billing, Cost Management, and Account consoles | Write |  |  |
UpdateCostAllocationTagsStatus | Grants permission to update existing Cost Allocation Tags status | Write |  |  |
UpdateCostCategoryDefinition | Grants permission to update an existing Cost Category | Write | costcategory* |  |
| aws:ResourceTag/${TagKey} |
UpdateNotificationSubscription [permission only] | Grants permission to update Reservation expiration alerts | Write |  |  |
UpdatePreferences [permission only] | Grants permission to edit Cost Explorer Preferences page | Write |  |  |
UpdateReport [permission only] | Grants permission to update Cost Explorer Reports | Write |  |  |

## Resource types defined by AWS Cost Explorer Service

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the Resource types table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
anomalysubscription | `arn:$ { Partition}:ce::$ { Account}:anomalysubscription/$ { Identifier}` | aws:ResourceTag/${TagKey}
anomalymonitor | `arn:$ { Partition}:ce::$ { Account}:anomalymonitor/$ { Identifier}` | aws:ResourceTag/${TagKey}
costcategory | `arn:$ { Partition}:ce::$ { Account}:costcategory/$ { Identifier}` | aws:ResourceTag/${TagKey}

## Condition keys for AWS Cost Explorer Service

AWS Cost Explorer Service defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters access by the tags that are passed in the request | String
aws:ResourceTag/${TagKey} | Filters access by the tags associated with the resource | String
aws:TagKeys | Filters access by the tag keys that are passed in the request | ArrayOfString

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.